From 1d0a86a6eae427753e237ef541f29096c266168f Mon Sep 17 00:00:00 2001
From: Simon Jackson <si@sonocent.com>
Date: Wed, 1 Apr 2020 16:34:21 +0100
Subject: [PATCH] Basic CMake support

---
 .gitignore     |  2 ++
 CMakeLists.txt | 51 ++++++++++++++++++++++++++++++++++++++++++++++++++
 2 files changed, 53 insertions(+)
 create mode 100644 CMakeLists.txt

diff --git a/.gitignore b/.gitignore
index 574d0c0..86dbd88 100644
--- a/.gitignore
+++ b/.gitignore
@@ -5,6 +5,7 @@
 *.o
 *.sw*
 *~
+.ccls-cache/
 .deps
 .dirstamp
 .libs
@@ -12,6 +13,7 @@
 Makefile.in
 aclocal.m4
 autom4te.cache/
+build/
 config.guess
 config.log
 config.status
diff --git a/CMakeLists.txt b/CMakeLists.txt
new file mode 100644
index 0000000..f14786b
--- /dev/null
+++ b/CMakeLists.txt
@@ -0,0 +1,51 @@
+cmake_minimum_required(VERSION 3.1)
+project(opusfile LANGUAGES C VERSION 0.11)
+
+# Required modules
+include(GNUInstallDirs)
+
+# Disable in-source builds to prevent source tree corruption.
+if(" ${CMAKE_SOURCE_DIR}" STREQUAL " ${CMAKE_BINARY_DIR}")
+    message(FATAL_ERROR "FATAL: In-source builds are not allowed.
+       You should create a separate directory for build files."
+    )
+endif()
+
+option(BUILD_SHARED_LIBS "Build shared library" OFF)
+
+add_library(opusfile 
+    src/info.c
+    src/internal.c
+    src/internal.h
+    src/opusfile.c
+    src/stream.c
+    include/opusfile.h
+)
+
+set_target_properties(
+    opusfile PROPERTIES
+    PUBLIC_HEADER "include/opusfile.h"
+)
+
+target_compile_options(opusfile PRIVATE -std=c89)
+
+find_library(OGG_PATH ogg)
+find_library(OPUS_PATH opus)
+target_link_libraries(opusfile "${OGG_PATH}" "${OPUS_PATH}")
+
+find_path(OPUS_MULTISTREAM_H "opus_multistream.h" PATH_SUFFIXES "opus")
+find_path(OGG_H "ogg.h" PATH_SUFFIXES "ogg")
+target_include_directories(opusfile PUBLIC 
+    "${OPUS_MULTISTREAM_H}" 
+    "${OGG_H}/.."
+    $<BUILD_INTERFACE:${CMAKE_CURRENT_SOURCE_DIR}/include>
+    $<BUILD_INTERFACE:${CMAKE_CURRENT_BINARY_DIR}/include>
+    $<INSTALL_INTERFACE:${CMAKE_INSTALL_INCLUDEDIR}>
+)
+
+install(TARGETS opusfile
+        ARCHIVE DESTINATION ${CMAKE_INSTALL_LIBDIR}
+        LIBRARY DESTINATION ${CMAKE_INSTALL_LIBDIR}
+        RUNTIME DESTINATION ${CMAKE_INSTALL_BINDIR}
+        PUBLIC_HEADER DESTINATION ${CMAKE_INSTALL_INCLUDEDIR}/opusfile
+)
-- 
2.25.0

